@@ -2,7 +2,7 @@ package Test::Should::Engine;
 use strict;
 use warnings;
 use 5.010001;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Carp ();
 use Storable ();
@@ -15,8 +15,12 @@ sub run {
     if ($pattern =~ /^should_not_(.+)$/) {
         $pattern = "should_$1";
         return !$class->run($pattern, $subject, @args);
-    } elsif ($pattern =~ 'should_be_ok') {
+    } elsif ($pattern eq 'should_be_ok' || $pattern eq 'should_be_true') {
         return !!$subject;
+    } elsif ($pattern eq 'should_be_false') {
+        return !$subject;
+    } elsif ($pattern eq 'should_be_undef') {
+        return not defined($subject);
     } elsif ($pattern eq 'should_be_empty') {
         if (ref $subject eq 'ARRAY') {
             return (@$subject == 0);
